@@ -18,6 +18,7 @@ from pyunv.manifest import Manifest
 
 
 class ReaderTests(unittest.TestCase):
+    
     def setUp(self):
         super(ReaderTests, self).setUp()
     
@@ -25,19 +26,20 @@ class ReaderTests(unittest.TestCase):
         super(ReaderTests, self).tearDown()
             
     def test_date_from_dateindex1(self):
-        date = datetime.date(1976,7,4)
+        date = datetime.date(1976, 7, 4)
         self.assertEqual(Reader.date_from_dateindex(2442964), date)
         
     def test_date_from_dateindex2(self):
-        date = datetime.date(1976,7,5)
+        date = datetime.date(1976, 7, 5)
         self.assertEqual(Reader.date_from_dateindex(2442965), date)
         
     def test_date_from_dateindex3(self):
-        date = datetime.date(2009,9,15)
+        date = datetime.date(2009, 9, 15)
         self.assertEqual(Reader.date_from_dateindex(2455090), date)
         
 
 class SampleUniverseXIR2(unittest.TestCase):
+    
     def setUp(self):
         super(SampleUniverseXIR2, self).setUp()
         self.filename = 'pyunv/tests/universes/universe_xir2.unv'
@@ -48,12 +50,8 @@ class SampleUniverseXIR2(unittest.TestCase):
         del self.reader
             
     def test_manifest(self):
-        universe = self.reader.universe
-        f = open(self.filename+'.txt', 'w')
-        Manifest().save(f, universe)
-        f.close()
+        Manifest(self.reader.universe).save(open(self.filename+'.txt', 'w'))
         
 
 if __name__ == '__main__':
     unittest.main()
-
