@@ -15,8 +15,7 @@ from repr import repr
 
 
 class Universe(object):
-    
-    """docstring for Universe"""
+
     def __init__(self, id_=None, name=None, description=None):
         super(Universe, self).__init__()
         self.id_ = id_
@@ -52,26 +51,28 @@ class Universe(object):
     
     @property
     def statistics(self):
+        
         class Counter(ClassVisitor):
+            
             def __init__(self):
                 super(Counter, self).__init__()
                 self.classes = 0
                 self.objects = 0
                 self.conditions = 0
-                
+            
             def visit_class(self, cls):
                 self.classes += 1
-    
+            
             def visit_object(self, obj):
                 self.objects += 1
-
+            
             def visit_condition(self, cond):
                 self.conditions += 1
         
         counter = Counter()
         for c in self.classes:
             c.accept(counter)
-            
+        
         stats = dict()
         stats["classes"] = counter.classes
         stats["objects"] = counter.objects
@@ -82,10 +83,10 @@ class Universe(object):
         # stats["hierarchies"] =
         stats["conditions"] = counter.conditions
         return stats
-        
+
 
 class Parameters(object):
-    """docstring for Parameters"""
+    
     def __init__(self):
         super(Parameters, self).__init__()
         self.universe_filename = None
@@ -109,7 +110,6 @@ class Parameters(object):
 
 class Class(object):
     
-    """docstring for Class"""
     def __init__(self, universe, id_, parent, name, description):
         super(Class, self).__init__()
         self.universe = universe
@@ -120,7 +120,7 @@ class Class(object):
         self.objects = []
         self.conditions = []
         self.subclasses = []
-
+    
     def accept(self, visitor):
         visitor.visit_class(self)
         for o in self.objects:
@@ -133,7 +133,6 @@ class Class(object):
 
 class Join(object):
     
-    """docstring for Join"""
     def __init__(self, universe, id_):
         super(Join, self).__init__()
         self.universe = universe
@@ -145,7 +144,8 @@ class Join(object):
     @property
     def statement(self):
         if self.term_count == 2:
-            s = self.fullterm(self.terms[0]) + self.expression + self.fullterm(self.terms[1])
+            s = self.fullterm(self.terms[0]) + self.expression + \
+                self.fullterm(self.terms[1])
         else:
             format = self.expression.replace(chr(1), '%s')
             s = format % tuple([self.fullterm(t) for t in self.terms])
@@ -159,7 +159,6 @@ class Join(object):
 
 class Context(object):
     
-    """docstring for Join"""
     def __init__(self, universe, id_, name, description):
         super(Context, self).__init__()
         self.universe = universe
@@ -167,15 +166,14 @@ class Context(object):
         self.name = name
         self.description = description
         self.joins = []
-
+    
     @property
     def join_list(self):
         return ', '.join([str(join_id) for join_id in self.joins])
-        
-        
+
+
 class ObjectBase(object):
     
-    """docstring for ObjectBase"""
     def __init__(self, universe, id_, parent, name, description):
         super(ObjectBase, self).__init__()
         assert(universe)
@@ -189,14 +187,14 @@ class ObjectBase(object):
         self.select = None
         self.where = None
         self.visible = True
-
+    
     @property
     def fullname(self):
         if self.parent:
             return '%s.%s' % (self.parent.name, self.name)
         else:
             return self.name
-
+    
     def lookup_table(self, match):
         table_id = int(match.groups()[0])
         return self.universe.table_map[table_id].name
@@ -214,23 +212,22 @@ class ObjectBase(object):
             return p.sub(self.lookup_object, expanded_sql)
         else:
             return None
-        
+    
     @property
     def select_sql(self):
         return self.expand_sql(self.select)
-
+    
     @property
     def where_sql(self):
         return self.expand_sql(self.where)
-
+    
     def __str__(self):
-        return '%s id=%d, name=%s, select=%s' % (type(self), 
-            self.id_, self.name, self.select) 
+        return '%s id=%d, name=%s, select=%s' % (type(self),
+            self.id_, self.name, self.select)
+
 
-       
 class Object(ObjectBase):
     
-    """docstring for Object"""
     def __init__(self, universe, id_, parent, name, description):
         super(Object, self).__init__(universe, id_, parent, name, description)
         self.format = None
@@ -238,25 +235,25 @@ class Object(ObjectBase):
     
     @classmethod
     def unknown(cls):
-        return Object(None, -1, None, "Unknown", "This object has been deleted from the universe")
-
+        return Object(None, -1, None, "Unknown", 
+            "This object has been deleted from the universe")
+    
     def accept(self, visitor):
         visitor.visit_object(self)
 
 
 class Condition(ObjectBase):
     
-    """docstring for Condition"""
     def __init__(self, universe, id_, parent, name, description):
-        super(Condition, self).__init__(universe, id_, parent, name, description)
-
+        super(Condition, self).__init__(universe, id_, 
+            parent, name, description)
+    
     def accept(self, visitor):
         visitor.visit_condition(self)
 
 
 class Table(object):
-
-    """docstring for Table"""
+    
     def __init__(self, universe, id_, parent_id, name, schema):
         super(Table, self).__init__()
         self.universe = universe
@@ -264,7 +261,7 @@ class Table(object):
         self.parent_id = parent_id
         self.name = name
         self.schema = schema
-
+    
     @property
     def fullname(self):
         if self.schema:
@@ -272,63 +269,64 @@ class Table(object):
         else:
             s = self.name
         if self.is_alias:
-            s += ' (alias for %s)' % self.universe.table_map[self.parent_id].fullname
+            s += ' (alias for %s)' % self.universe.table_map[
+                self.parent_id].fullname
         return s
     
     @property
     def is_alias(self):
         return self.parent_id != 0
-
+    
     def __str__(self):
-        return '%s id=%d, schema=%s name=%s' % (type(self), 
-            self.id_, self.schema, self.name) 
-
+        return '%s id=%d, schema=%s name=%s' % (type(self),
+            self.id_, self.schema, self.name)
+    
     @classmethod
     def unknown(cls):
         return Table(None, -1, -1, None, "Unknown")
-        
+
 
 class VirtualTable(object):
-
-    """docstring for VirtualTable"""
+    
     def __init__(self, universe, table_id=None, select=None):
         super(VirtualTable, self).__init__()
         self.universe = universe
         self.table_id = table_id
         self.select = select
-
+    
     def __str__(self):
-        return '%s table_id=%d, select=%s' % (type(self), 
-            self.table_id, self.select) 
+        return '%s table_id=%d, select=%s' % (type(self),
+            self.table_id, self.select)
 
 
 class Column(object):
-
-    """docstring for Column"""
+    
     def __init__(self, id_=None, name=None, parent=None, universe=None):
         super(Column, self).__init__()
         self.id_ = id_
         self.name = name
         self.parent = parent
         self.universe = universe
-
+    
     @property
     def fullname(self):
         if self.parent:
             return '%s.%s' % (self.parent.name, self.name)
         else:
             return self.name
-
+    
     def __cmp__(self, other):
         return cmp(self.id_, other.id_)
-        
+    
     def __str__(self):
-        return '%s id=%d, name=%s parent=%d' % (type(self), 
-            self.id_, self.name, self.parent) 
-        
+        return '%s id=%d, name=%s parent=%d' % (type(self),
+            self.id_, self.name, self.parent)
+
 
 class ClassVisitor(object):
+    
     """Visits each node in the class, object, and condition hierarchy"""
+    
     def __init__(self):
         super(ClassVisitor, self).__init__()
     
@@ -339,8 +337,7 @@ class ClassVisitor(object):
     def visit_object(self, obj):
         """docstring for visit_object"""
         pass
-
+    
     def visit_condition(self, condition):
         """docstring for visit_condition"""
         pass
-        
\ No newline at end of file
